# -*- coding: utf-8 -*-

# ****************************************************************
# IDE: PyCharm
# Developed by: JhonyAlexanderGonzal
# Date: 19/05/2023 8:25 a. m.
# Project: cfhl-backend
# Module Name: stats
# ****************************************************************

from oasis.models import Stat
from zibanu.django.rest_framework import serializers


class StatSerializer(serializers.ModelSerializer):
    class Meta:
        model = Stat
        fields = ("id", "name", "is_staff")



# -*- coding: utf-8 -*-

# ****************************************************************
# IDE: PyCharm
# Developed by: JhonyAlexanderGonzal
# Date: 18/05/2023 5:23 p. m.
# Project: cfhl-backend
# Module Name: stats
# ****************************************************************

import base64
from datetime import date
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from django.core.exceptions import ValidationError as CoreValidationError
from django.utils.translation import gettext_lazy as _
from oasis.models import Stat
from oasis.stats.api.serializers import StatSerializer
from rest_framework import status
from rest_framework.response import Response
from zibanu.django.repository.lib.utils import DocumentGenerator
from zibanu.django.rest_framework.exceptions import APIException
from zibanu.django.rest_framework.exceptions import ValidationError
from zibanu.django.rest_framework.viewsets import ViewSet
from zibanu.django.utils import CodeGenerator
from zibanu.django.utils import Email
from zibanu.django.utils import ErrorMessages


class StatsServices(ViewSet):
    permission_classes = []
    authentication_classes = []

    def list(self, request) -> Response:
        """
        REST Service to get a list of stats
        :param request: request object from HTTP Post.
        :return: response object with status and data
        """

        try:
            qs = Stat.objects.filter(enabled=True)
            serializer = StatSerializer(instance=qs, many=True)
            data_return = serializer.data
            status_return = status.HTTP_200_OK if len(data_return) > 0 else status.HTTP_204_NO_CONTENT
        except Exception as exc:
            raise APIException(ErrorMessages.NOT_CONTROLLED, str(exc),
                               http_status=status.HTTP_500_INTERNAL_SERVER_ERROR)
        else:
            return Response(status=status_return, data=data_return)



# -*- coding: utf-8 -*-

# ****************************************************************
# IDE: PyCharm
# Developed by: JhonyAlexanderGonzal
# Date: 18/05/2023 2:14 p. m.
# Project: cfhl-backend
# Module Name: apps
# ****************************************************************

from django.apps import AppConfig


class StatsConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'oasis.stats'
    label = "stats"



# Generated by Django 4.2.1 on 2023-05-18 21:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oasis', '0018_offermov'),
    ]

    operations = [
        migrations.CreateModel(
            name='Stat',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=120, verbose_name='Stat name')),
                ('query_text', models.TextField(help_text='Text used to execute the query', verbose_name='Query Text')),
                ('is_staff', models.BooleanField(default=True, help_text='It is required to be staff to see the stat', verbose_name='Is staff')),
                ('enabled', models.BooleanField(default=True, verbose_name='Enabled')),
            ],
            options={
                'verbose_name': 'Stat',
                'verbose_name_plural': 'Stats',
            },
        ),
    ]



# -*- coding: utf-8 -*-

# ****************************************************************
# IDE: PyCharm
# Developed by: JhonyAlexanderGonzal
# Date: 18/05/2023 4:21 p. m.
# Project: cfhl-backend
# Module Name: admin
# ****************************************************************

from django.contrib import admin
from oasis.models import Stat


@admin.register(Stat)
class StatAdmin(admin.ModelAdmin):
    pass



# -*- coding: utf-8 -*-

# ****************************************************************
# IDE: PyCharm
# Developed by: JhonyAlexanderGonzal
# Date: 19/05/2023 8:46 a. m.
# Project: cfhl-backend
# Module Name: urls
# ****************************************************************

from oasis.stats.api import services
from django.urls import path
from rest_framework.routers import DefaultRouter

routers = DefaultRouter()

urlpatterns = [
    path(r"list/", services.StatsServices.as_view({"post": "list"})),
]
